/* THIS FILE IS AUTOGENERATED FROM SocketCommon.webidl BY Codegen.py - DO NOT EDIT */

#ifndef mozilla_dom_SocketCommonBinding_h
#define mozilla_dom_SocketCommonBinding_h

#include "js/RootingAPI.h"
#include "jspubtd.h"
#include "mozilla/ErrorResult.h"
#include "mozilla/dom/BindingDeclarations.h"
#include "mozilla/dom/Nullable.h"

namespace mozilla {
namespace dom {

struct NativePropertyHooks;
class ProtoAndIfaceCache;

} // namespace dom
} // namespace mozilla

namespace mozilla {
namespace dom {

enum class SocketReadyState : uint32_t {
  Opening,
  Open,
  Closing,
  Closed,
  Halfclosed,
  EndGuard_
};

namespace SocketReadyStateValues {
extern const EnumEntry strings[6];
} // namespace SocketReadyStateValues


} // namespace dom
} // namespace mozilla

#endif // mozilla_dom_SocketCommonBinding_h
