/* THIS FILE IS AUTOGENERATED BY generate-stylestructlist.py - DO NOT EDIT */

// IWYU pragma: private, include "nsStyleStructFwd.h"

/*
 * list of structs that contain the data provided by nsStyleContext, the
 * internal API for computed style data for an element
 */

/*
 * This file is intended to be used by different parts of the code, with
 * the STYLE_STRUCT macro (or the STYLE_STRUCT_INHERITED and
 * STYLE_STRUCT_RESET pair of macros) defined in different ways.
 */

#ifndef STYLE_STRUCT_INHERITED
#define STYLE_STRUCT_INHERITED(name, checkdata_cb) \
  STYLE_STRUCT(name, checkdata_cb)
#define UNDEF_STYLE_STRUCT_INHERITED
#endif

#ifndef STYLE_STRUCT_RESET
#define STYLE_STRUCT_RESET(name, checkdata_cb) \
  STYLE_STRUCT(name, checkdata_cb)
#define UNDEF_STYLE_STRUCT_RESET
#endif

#ifndef STYLE_STRUCT_DEP
#define STYLE_STRUCT_DEP(dep)
#define UNDEF_STYLE_STRUCT_DEP
#endif

#ifndef STYLE_STRUCT_END
#define STYLE_STRUCT_END()
#define UNDEF_STYLE_STRUCT_END
#endif

// The inherited structs are listed before the Reset structs.
// nsStyleStructID assumes this is the case, and callers other than
// nsStyleStructFwd.h that want the structs in id-order just define
// STYLE_STRUCT rather than including the file twice.


STYLE_STRUCT_INHERITED(Font, CheckFontCallback)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_DEP(Visibility)
STYLE_STRUCT_END()
STYLE_STRUCT_INHERITED(Color, CheckColorCallback)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_END()
STYLE_STRUCT_INHERITED(List, nullptr)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_DEP(Font)
STYLE_STRUCT_DEP(Visibility)
STYLE_STRUCT_END()
STYLE_STRUCT_INHERITED(Text, CheckTextCallback)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_DEP(Font)
STYLE_STRUCT_DEP(Visibility)
STYLE_STRUCT_DEP(Color)
STYLE_STRUCT_END()
STYLE_STRUCT_INHERITED(Visibility, nullptr)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_END()
STYLE_STRUCT_INHERITED(Quotes, nullptr)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_END()
STYLE_STRUCT_INHERITED(UserInterface, nullptr)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_END()
STYLE_STRUCT_INHERITED(TableBorder, nullptr)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_DEP(Font)
STYLE_STRUCT_DEP(Visibility)
STYLE_STRUCT_END()
STYLE_STRUCT_INHERITED(SVG, nullptr)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_DEP(Font)
STYLE_STRUCT_DEP(Visibility)
STYLE_STRUCT_DEP(Color)
STYLE_STRUCT_END()
STYLE_STRUCT_INHERITED(Variables, CheckVariablesCallback)
STYLE_STRUCT_END()
STYLE_STRUCT_RESET(Background, nullptr)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_DEP(Font)
STYLE_STRUCT_DEP(Visibility)
STYLE_STRUCT_DEP(Color)
STYLE_STRUCT_END()
STYLE_STRUCT_RESET(Position, nullptr)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_DEP(Font)
STYLE_STRUCT_DEP(Visibility)
STYLE_STRUCT_END()
STYLE_STRUCT_RESET(TextReset, nullptr)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_DEP(Font)
STYLE_STRUCT_DEP(Visibility)
STYLE_STRUCT_DEP(Color)
STYLE_STRUCT_END()
STYLE_STRUCT_RESET(Display, nullptr)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_DEP(Font)
STYLE_STRUCT_DEP(Visibility)
STYLE_STRUCT_END()
STYLE_STRUCT_RESET(Content, nullptr)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_DEP(Font)
STYLE_STRUCT_DEP(Visibility)
STYLE_STRUCT_END()
STYLE_STRUCT_RESET(UIReset, nullptr)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_END()
STYLE_STRUCT_RESET(Table, nullptr)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_END()
STYLE_STRUCT_RESET(Margin, nullptr)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_DEP(Font)
STYLE_STRUCT_DEP(Visibility)
STYLE_STRUCT_END()
STYLE_STRUCT_RESET(Padding, nullptr)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_DEP(Font)
STYLE_STRUCT_DEP(Visibility)
STYLE_STRUCT_END()
STYLE_STRUCT_RESET(Border, nullptr)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_DEP(Font)
STYLE_STRUCT_DEP(Visibility)
STYLE_STRUCT_DEP(Color)
STYLE_STRUCT_END()
STYLE_STRUCT_RESET(Outline, nullptr)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_DEP(Font)
STYLE_STRUCT_DEP(Visibility)
STYLE_STRUCT_DEP(Color)
STYLE_STRUCT_END()
STYLE_STRUCT_RESET(XUL, nullptr)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_END()
STYLE_STRUCT_RESET(SVGReset, nullptr)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_DEP(Font)
STYLE_STRUCT_DEP(Visibility)
STYLE_STRUCT_DEP(Color)
STYLE_STRUCT_END()
STYLE_STRUCT_RESET(Column, nullptr)
STYLE_STRUCT_DEP(Variables)
STYLE_STRUCT_DEP(Font)
STYLE_STRUCT_DEP(Visibility)
STYLE_STRUCT_DEP(Color)
STYLE_STRUCT_END()

#ifdef UNDEF_STYLE_STRUCT_INHERITED
#undef STYLE_STRUCT_INHERITED
#undef UNDEF_STYLE_STRUCT_INHERITED
#endif

#ifdef UNDEF_STYLE_STRUCT_RESET
#undef STYLE_STRUCT_RESET
#undef UNDEF_STYLE_STRUCT_RESET
#endif

#ifdef UNDEF_STYLE_STRUCT_DEP
#undef STYLE_STRUCT_DEP
#undef UNDEF_STYLE_STRUCT_DEP
#endif

#ifdef UNDEF_STYLE_STRUCT_END
#undef STYLE_STRUCT_END
#undef UNDEF_STYLE_STRUCT_END
#endif

